@@ -17,7 +17,6 @@
 
 from ai.h2o.sparkling.ml.params.H2OMOJOModelParams import H2OSupervisedMOJOModelParams
 from pyspark.ml.util import _jvm
-from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
@@ -34,17 +33,6 @@ class H2OGAMMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO, HasGam
         javaModel = _jvm().ai.h2o.sparkling.ml.models.H2OGAMMOJOModel.createFromMojo(pathToMojo, settings.toJavaObject())
         return H2OGAMMOJOModel(javaModel)
 
-
-    def getCrossValidationModels(self):
-        cvModels = self._java_obj.getCrossValidationModelsAsArray()
-        if cvModels is None:
-            return None
-        elif isinstance(cvModels, JavaObject):
-            return [H2OGAMMOJOModel(v) for v in cvModels]
-        else:
-            raise TypeError("Invalid type.")
-
-
     def getFamily(self):
         value = self._java_obj.getFamily()
         return value
@@ -205,16 +193,6 @@ class H2OGAMMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO, HasGam
         return H2OTypeConverters.scalaArrayToPythonArray(value)
 
 
-    def getSplineOrders(self):
-        value = self._java_obj.getSplineOrders()
-        return H2OTypeConverters.scalaArrayToPythonArray(value)
-
-
-    def getSplinesNonNegative(self):
-        value = self._java_obj.getSplinesNonNegative()
-        return H2OTypeConverters.scalaArrayToPythonArray(value)
-
-
     def getScale(self):
         value = self._java_obj.getScale()
         return H2OTypeConverters.scalaArrayToPythonArray(value)
@@ -328,6 +306,3 @@ class H2OGAMMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO, HasGam
     def getAucType(self):
         value = self._java_obj.getAucType()
         return value
-
-    # Outputs
-
